var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { action, runInAction, observable } from 'mobx';
import SQLite from './SQLite';
export default class SQLiteMobxModel {
    async loadItems(params) {
        const { select, join, where } = getQueryParams(params);
        const resp = await SQLite.query(`SELECT ${select} FROM ${this.table} ${join} WHERE ${where}`);
        runInAction(() => {
            this.data = resp.toArray() || [];
            this.lastParams = params;
        });
    }
    async setItems(items) {
        await SQLite.truncateTable(this.table);
        const result = await SQLite.insertMany(this.table, items);
        this.loadItems(this.lastParams);
        return result;
    }
    async addItems(items) {
        const result = await SQLite.insertMany(this.table, items);
        this.loadItems(this.lastParams);
        return result;
    }
    async addItem(item) {
        const result = await SQLite.insert(this.table, item);
        this.loadItems(this.lastParams);
        return result;
    }
    async setItem(item) {
        const result = await SQLite.insertOrReplace(this.table, item);
        this.loadItems(this.lastParams);
        return result;
    }
    async getItem(id) {
        // TODO: implement this
    }
    async editItem(item) {
        // TODO: implement this
    }
    async removeItem(item) {
        const result = await SQLite.query(`DELETE FROM ${this.table} WHERE id = ${item.id}`);
        this.loadItems(this.lastParams);
        return result;
    }
    clear() {
        this.lastParams = undefined;
        this.data = [];
    }
    async truncate() {
        const result = await SQLite.truncateTable(this.table);
        runInAction(() => this.clear());
        return result;
    }
}
__decorate([
    observable
], SQLiteMobxModel.prototype, "lastParams", void 0);
__decorate([
    action.bound
], SQLiteMobxModel.prototype, "loadItems", null);
__decorate([
    action.bound
], SQLiteMobxModel.prototype, "setItems", null);
__decorate([
    action.bound
], SQLiteMobxModel.prototype, "addItems", null);
__decorate([
    action.bound
], SQLiteMobxModel.prototype, "addItem", null);
__decorate([
    action.bound
], SQLiteMobxModel.prototype, "setItem", null);
__decorate([
    action.bound
], SQLiteMobxModel.prototype, "getItem", null);
__decorate([
    action.bound
], SQLiteMobxModel.prototype, "editItem", null);
__decorate([
    action.bound
], SQLiteMobxModel.prototype, "removeItem", null);
__decorate([
    action.bound
], SQLiteMobxModel.prototype, "clear", null);
__decorate([
    action.bound
], SQLiteMobxModel.prototype, "truncate", null);
function getQueryParams(p) {
    if (p) {
        return {
            select: p.select || '*',
            join: p.join || '',
            where: p.where || '1'
        };
    }
    else {
        return {
            select: '*',
            join: '',
            where: '1'
        };
    }
}
//# sourceMappingURL=SQLiteMobxModel.js.map