import SQLite from './SQLite';
class SQLiteMobxColumn {
    constructor(name, type, size) {
        this._name = name;
        this._type = type;
        this._size = size;
        return this;
    }
    autoIncrement(value = true) {
        this._autoIncrement = value;
        return this;
    }
    nullable(value = true) {
        this._nullable = value;
        return this;
    }
    default(value) {
        this._default = value;
        return this;
    }
    toSQL() {
        let sql = `${this._name} ${this._type}`;
        // Add column size
        if (this._size) {
            sql += `(${this._size})`;
        }
        // SET Autoincrement
        if (this._autoIncrement) {
            sql += ' AUTOINCREMENT';
        }
        // Add Nullable
        if (this._nullable) {
            sql += ' NULL';
        }
        else {
            sql += ' NOT NULL';
        }
        // SET Default value
        if (this._default) {
            sql += ` DEFAULT ${this._default}`;
        }
        // Add Finish comma
        return sql + ',\n';
    }
}
class SQLiteMobxTable {
    constructor(name) {
        this._columns = {};
        this._name = name;
    }
    primary(param = 'id') {
        const column = new SQLiteMobxColumn(param, 'INTEGER PRIMARY KEY', 0);
        return (this._columns[param] = column.autoIncrement().nullable(false));
    }
    string(param, size = 50) {
        return (this._columns[param] = new SQLiteMobxColumn(param, 'VARCHAR', size));
    }
    integer(param, size = 11) {
        return (this._columns[param] = new SQLiteMobxColumn(param, 'INTEGER', size));
    }
    boolean(param, size = 0) {
        return (this._columns[param] = new SQLiteMobxColumn(param, 'BOOLEAN', size));
    }
    double(param) {
        return (this._columns[param] = new SQLiteMobxColumn(param, 'DOUBLE', 0));
    }
    date(param) {
        return (this._columns[param] = new SQLiteMobxColumn(param, 'DATE', 0));
    }
    ifNotExists(value = true) {
        this._ifNotExists = value;
    }
    toSQL() {
        let sql = 'CREATE TABLE';
        // Add IF NOT EXISTS
        if (this._ifNotExists) {
            sql += ' IF NOT EXISTS';
        }
        // Set Column name and starts block
        sql += ` ${this._name} (\n`;
        // Add Column list
        for (const key in this._columns) {
            sql += this._columns[key].toSQL();
        }
        // Remove last comma and finish block
        return sql.replace(/,\n$/g, '\n);');
    }
}
class SQLiteMobxSchema {
    static create(name, actioner) {
        // Cria uma tabela com o seguinte nome
        const table = new SQLiteMobxTable(name);
        // Inicia com chave primária
        table.primary();
        // Chama o table builder
        actioner(table);
        // Cria a tabela
        return SQLite.query(table.toSQL());
    }
    static drop(name) {
        return SQLite.query(`DROP TABLE ${name}`);
    }
    static dropIfExists(name) {
        return SQLite.query(`DROP TABLE IF EXISTS ${name}`);
    }
    static async hasTable(name) { }
    static async hasColumn(...columns) { }
}
export { SQLiteMobxTable, SQLiteMobxColumn };
export default SQLiteMobxSchema;
//# sourceMappingURL=SQLiteMobxSchema.js.map